@@ -17,7 +17,7 @@ class DingDingPlugin(NotificationPlugin):
     """
     author = 'dreamerldq'
     author_url = 'https://github.com/dreamerldq/sentry-dingding-format'
-    version = '1.0.8'
+    version = '1.0.9'
     description = 'Send project error counts to DingDing .'
     resource_links = [
         ('Source', 'https://github.com/cench/sentry-10-dingding'),
@@ -57,13 +57,13 @@ class DingDingPlugin(NotificationPlugin):
         data = {
             "msgtype": "markdown",
             "markdown": {
-                "event": str(event),
                 "title": title,
-                "text": u"#### {title} \n\n > {message} \n\n > 设备:{device} \n\n > UID:{uid} \n\n > {path} \n\n [详细信息]({url})".format(
+                "text": u"#### {title} \n\n > {message} \n\n > 设备:{device} \n\n > Event:{event} \n\n > UID:{uid} \n\n > {path} \n\n [详细信息]({url})".format(
                     title=title,
                     device=event.get_tag('device'),
                     uid=event.get_tag('uid'),
                     path=event.get_tag('url'),
+                    event=str(event),
                     message=event.title or event.message,
                     url=u"{}events/{}/".format(group.get_absolute_url(), event.event_id),
                 )
